@@ -10,6 +10,8 @@ import math
 import torch
 import argparse
 
+from transformers import PreTrainedTokenizerBase
+
 from flexneuart.config import DEFAULT_DEVICE_GPU
 from transformers import AutoTokenizer, AutoModel
 from flexneuart.models import model_registry
@@ -17,7 +19,7 @@ from flexneuart.models import model_registry
 # An attribute to store the main BERT encoder
 BERT_ATTR='bert'
 
-def init_model(obj_ref, bert_flavor):
+def init_model(obj_ref, bert_flavor : str):
     """Instantiate a model, a tokenizer, and remember their parameters.
 
     :param obj_ref:       an object to initialize.
@@ -27,10 +29,14 @@ def init_model(obj_ref, bert_flavor):
     obj_ref.BERT_MODEL = bert_flavor
 
     model = AutoModel.from_pretrained(bert_flavor)
+
     config = model.config
     setattr(obj_ref, BERT_ATTR, model)
     obj_ref.config = config
-    obj_ref.tokenizer = tokenizer = AutoTokenizer.from_pretrained(bert_flavor)
+
+    tokenizer: PreTrainedTokenizerBase = AutoTokenizer.from_pretrained(bert_flavor)
+    obj_ref.tokenizer = tokenizer
+    obj_ref.no_token_type_ids = not 'token_type_ids' in tokenizer.model_input_names
 
     obj_ref.CHANNELS = config.num_hidden_layers + 1
     obj_ref.BERT_SIZE = config.hidden_size
@@ -42,7 +48,8 @@ def init_model(obj_ref, bert_flavor):
     print('Model type:', obj_ref.BERT_MODEL,
           '# of channels:', obj_ref.CHANNELS,
           'hidden layer size:', obj_ref.BERT_SIZE,
-          'input window size:', obj_ref.MAXLEN)
+          'input window size:', obj_ref.MAXLEN,
+          'no token type IDs:', obj_ref.no_token_type_ids)
 
 
 #
@@ -117,29 +124,33 @@ def sliding_window_subbatch(toks, window_size, stride):
 
 
 def add_model_init_basic_args(parser, add_device_name, add_init_model_weights, mult_model):
+    parser.add_argument('--amp', action='store_true',
+                        help="Use automatic mixed-precision")
+
     model_list = list(model_registry.registered.keys())
-    parser.add_argument('--model_name', metavar='model_name',
-                        help='a model to use: ' + ', '.join(model_list),
-                        choices=model_list,
-                        default=None)
 
     if add_init_model_weights:
         parser.add_argument('--init_model_weights',
                             metavar='model weights',
                             help='initial model weights will be loaded in non-strict mode',
-                            type=argparse.FileType('rb'), default=None)
+                            type=str, default=None)
 
     if not mult_model:
+        parser.add_argument('--model_name', metavar='model_name',
+                            help='a model to use: ' + ', '.join(model_list),
+                            choices=model_list,
+                            default=None)
+
         parser.add_argument('--init_model',
                             metavar='initial model',
                             help='previously serialized model',
-                            type=argparse.FileType('rb'), default=None)
+                            type=str, default=None)
     else:
         parser.add_argument('--init_model_list',
                             metavar='serialized models',
                             required=True,
                             help='previously serialized models',
-                            type=argparse.FileType('rb'),
+                            type=str,
                             nargs='+',
                             default=None)
 
