@@ -1,3 +1,4 @@
-#/bin/bash
+#/bin/bash -e
+source config.sh
 YahooAnswersCollectionSplitter $@
 
